import json
from os import getenv

import boto3
import requests
from elastic_paribhasha.base_elastic_index import constants
from requests_aws4auth import AWS4Auth


class BaseIndex(object):
    """
    Base class for Elastic indexes
    """
    def __init__(self):
        # Mandate HTTPS for encrypted data transfer
        self.protocol = 'https://'

        if not self.region:
            self.region = getenv(constants.AWS_REGION_NAME)

        self.credentials = boto3.Session().get_credentials()
        self.awsauth = AWS4Auth(self.credentials.access_key,
                                self.credentials.secret_key,
                                self.region,
                                'es',
                                session_token=self.credentials.token)

        if not self.elastic_url:
            self.elastic_url = getenv(constants.ELASTIC_DOMAIN_URL)

    def run_query(self, query):
        url = self.protocol + self.elastic_url + '/' + self.index_name + self.search_endpoint
        headers = {"Content-Type": "application/json"}
        return requests.get(url,
                            auth=self.awsauth,
                            headers=headers,
                            data=json.dumps(query))
